@@ -3,7 +3,7 @@ use 5.008_001;
 use strict;
 use warnings;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use Carp qw/croak/;
 use Array::Diff;
@@ -21,7 +21,7 @@ sub context {
 # don't override CORE::int
 use Pod::Functions ();
 my @column_methods =
-    grep {!$Pod::Functions::Type{$_}} keys(%SQL::Translator::Schema::Field::type_mapping), qw/tinyint string number/;
+    grep {!$Pod::Functions::Type{$_}} keys(%SQL::Translator::Schema::Field::type_mapping), qw/string number/;
 my @column_sugars  = qw/unique auto_increment unsigned null/;
 my @rev_column_sugars = qw/not_null signed/;
 my @export_dsls = qw/
@@ -351,7 +351,7 @@ DBIx::Schema::DSL - DSL for Database schema declaration
 
 =head1 VERSION
 
-This document describes DBIx::Schema::DSL version 0.08.
+This document describes DBIx::Schema::DSL version 0.09.
 
 =head1 SYNOPSIS
 
